package com.landray.kmss.sys.attachment.restservice.wps.controller;

import java.io.PrintWriter;
import com.landray.kmss.sys.print.util.SysPrintFileUtil;
import com.landray.kmss.sys.xform.base.service.ISysFormTemplateService;
import org.springframework.web.bind.annotation.PathVariable;
import com.landray.kmss.sys.filestore.scheduler.third.wps.center.util.WPSCenterCallBusinessUtil;
import com.landray.kmss.sys.filestore.convert.cache.ConvertQueueCache;
import com.landray.kmss.sys.filestore.scheduler.third.wps.center.cache.ConvertRedisCache;
import java.io.IOException;
import java.io.BufferedReader;
import com.landray.kmss.sys.attachment.integrate.wps.util.SysAttWpsCenterUtil;
import java.text.SimpleDateFormat;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RequestMethod;
import java.io.InputStream;
import com.landray.kmss.common.model.IBaseModel;
import org.springframework.web.multipart.MultipartFile;
import com.landray.kmss.sys.attachment.util.SysAttViewerUtil;
import java.util.Map;
import com.landray.kmss.sys.attachment.util.SysAttUtil;
import java.util.HashMap;
import java.util.Date;
import java.math.BigDecimal;
import com.landray.kmss.sys.attachment.restservice.wps.util.WpsUtil;
import org.springframework.web.bind.annotation.RequestParam;
import java.util.List;
import com.landray.kmss.sys.person.interfaces.PersonInfoServiceGetter;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import com.landray.kmss.sys.attachment.util.ImageCropUtil;
import com.landray.kmss.sys.zone.model.SysZonePersonInfo;
import org.springframework.web.bind.annotation.PostMapping;
import com.landray.kmss.sys.organization.model.SysOrgPerson;
import net.sf.json.JSONArray;
import net.sf.json.JSONObject;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.sys.organization.service.ISysOrgPersonService;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.GetMapping;
import com.landray.kmss.web.action.ActionForm;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.util.ResourceUtil;
import org.apache.commons.lang3.StringUtils;
import com.landray.kmss.util.SpringBeanUtil;
import org.slf4j.LoggerFactory;
import com.landray.kmss.sys.filestore.scheduler.third.wps.center.service.IWPSCenterCallbackResult;
import com.landray.kmss.sys.attachment.integrate.wps.interfaces.ISysAttachmentWpsCenterOfficeProvider;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import com.landray.kmss.sys.attachment.actions.SysAttMainAction;
import org.slf4j.Logger;
import com.landray.kmss.web.annotation.RestApi;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.landray.kmss.common.rest.controller.BaseController;

@RestController
@RequestMapping({ "/api/sys-attachment/wpsCenterCallback" })
@RestApi(docUrl = "/sys/attachment/restservice/sysAttWpsCenterRestServiceHelp.jsp", name = "SysAttWpsCenterCallbackController", resourceKey = "sys-attachment:SysAttWpsCenterCallback.title")
public class SysAttWpsCenterCallbackController extends BaseController
{
    private static final Logger logger;
    private SysAttMainAction sysAttMainAction;
    private ISysAttMainCoreInnerService sysAttMainService;
    private ISysAttachmentWpsCenterOfficeProvider sysAttachmentWpsCenterOfficeProvider;
    private IWPSCenterCallbackResult wpsCenterCallbackResult;
    
    static {
        logger = LoggerFactory.getLogger(SysAttWpsCenterCallbackController.class);
    }
    
    public SysAttWpsCenterCallbackController() {
        this.sysAttMainAction = new SysAttMainAction();
        this.wpsCenterCallbackResult = null;
    }
    
    private ISysAttMainCoreInnerService getSysAttMainService() {
        if (this.sysAttMainService == null) {
            this.sysAttMainService = (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
        }
        return this.sysAttMainService;
    }
    
    private ISysAttachmentWpsCenterOfficeProvider getSysAttachmentWpsCenterOfficeProvider() {
        if (this.sysAttachmentWpsCenterOfficeProvider == null) {
            this.sysAttachmentWpsCenterOfficeProvider = (ISysAttachmentWpsCenterOfficeProvider)SpringBeanUtil.getBean("wpsCenterProvider");
        }
        return this.sysAttachmentWpsCenterOfficeProvider;
    }
    
    private IWPSCenterCallbackResult getWpsCenterCallbackResult() {
        if (this.wpsCenterCallbackResult == null) {
            this.wpsCenterCallbackResult = (IWPSCenterCallbackResult)SpringBeanUtil.getBean("wpsCenterCallbackResultImp");
        }
        return this.wpsCenterCallbackResult;
    }
    
    private String generateDownloadUrl(final String fdId, final String token) throws Exception {
        String url = null;
        if (StringUtils.isNotEmpty(fdId)) {
            String urlPrefix = ResourceUtil.getKmssConfigString("kmss.innerUrlPrefix");
            if (StringUtils.isEmpty(urlPrefix)) {
                urlPrefix = ResourceUtil.getKmssConfigString("kmss.urlPrefix");
            }
            if (urlPrefix.endsWith("/")) {
                urlPrefix = urlPrefix.substring(0, urlPrefix.lastIndexOf("/"));
            }
            url = String.valueOf(urlPrefix) + "/api/sys-attachment/wpsCenterCallback/download?fdId=" + fdId + "&_w_l_token=" + token;
        }
        return url;
    }
    
    @GetMapping({ "/download" })
    public void download(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final long s = System.currentTimeMillis();
        final String w_l_token = request.getParameter("_w_l_token");
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调下载文件开始,入参_w_l_token = {}", w_l_token);
        }
        final Boolean ok = this.getSysAttachmentWpsCenterOfficeProvider().validateCallBackToken(w_l_token);
        if (!ok) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调下载文件失败,无效token,入参_w_l_token = {}", w_l_token);
            }
            response.setStatus(401);
            return;
        }
        this.sysAttMainAction.download(this.emptyMapping, (ActionForm)null, request, response);
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled() && SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调下载文件完成,耗时 = {},入参_w_l_token = {}", (Object)(System.currentTimeMillis() - s), w_l_token);
        }
    }
    
    @PostMapping({ "/v1/3rd/user/info" })
    public String getUserInfos(final HttpServletRequest request, final HttpServletResponse response, @RequestBody final String ids) throws Exception {
        String w_l_token = request.getParameter("_w_l_token");
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取用户信息开始,入参_w_l_token = {},ids = {}", w_l_token, ids);
        }
        w_l_token = this.handleLongToken(request, w_l_token);
        final Boolean ok = this.getSysAttachmentWpsCenterOfficeProvider().validateCallBackToken(w_l_token);
        if (!ok) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调获取用户信息失败,无效token,入参_w_l_token = {},ids = {}", w_l_token, ids);
            }
            response.setStatus(401);
            return null;
        }
        final ISysOrgPersonService sysOrgPersonService = (ISysOrgPersonService)SpringBeanUtil.getBean("sysOrgPersonService");
        if (StringUtil.isNotNull(ids)) {
            try {
                final long s = System.currentTimeMillis();
                final JSONObject paramJson = JSONObject.fromObject((Object)ids);
                if (paramJson.get("ids") != null) {
                    final JSONArray idArray = paramJson.getJSONArray("ids");
                    if (!idArray.isEmpty()) {
                        final JSONObject jsonObject = new JSONObject();
                        final JSONArray jsonArray = new JSONArray();
                        for (int i = 0; i < idArray.size(); ++i) {
                            final String id = idArray.getString(i);
                            final SysOrgPerson person = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(id, (Object)SysOrgPerson.class, true);
                            if (person != null) {
                                final JSONObject user = new JSONObject();
                                user.put((Object)"id", (Object)person.getFdId());
                                user.put((Object)"name", (Object)person.getFdName());
                                user.put((Object)"avatar_url", (Object)this.getPersonImage(person.getFdId()));
                                jsonArray.add((Object)user);
                            }
                        }
                        jsonObject.put((Object)"users", (Object)jsonArray);
                        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取用户信息完成,耗时 = {},入参_w_l_token = {},ids = {}", System.currentTimeMillis() - s, w_l_token, ids);
                        }
                        return jsonObject.toString();
                    }
                }
            }
            catch (final Exception e) {
                if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                    SysAttWpsCenterCallbackController.logger.error("解析wps请求参数异常", e);
                }
            }
        }
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取用户信息失败,异常入参,入参_w_l_token = {},ids = {}", w_l_token, ids);
        }
        response.setStatus(400);
        return null;
    }
    
    private String getPersonImage(final String personId) throws Exception {
        String personImageUrl = "";
        final String modelName = SysZonePersonInfo.class.getName();
        final String fdKey = "personPic" + ImageCropUtil.CROP_KEYS[0];
        List list = this.getSysAttMainService().findByModelKey(modelName, personId, fdKey);
        if (list.isEmpty()) {
            list = this.getSysAttMainService().findByModelKey(modelName, personId, "zonePersonInfo");
        }
        if (list != null && !list.isEmpty()) {
            final SysAttMain sysAtt = list.get(0);
            personImageUrl = this.generateDownloadUrl(sysAtt.getFdId(), this.getSysAttachmentWpsCenterOfficeProvider().getLongCallBackToken(personId, this.getSysAttachmentWpsCenterOfficeProvider().getWpsToken(), Boolean.valueOf(true)));
        }
        else {
            final String defaultHeadImageUrl = PersonInfoServiceGetter.getPersonDefaultHeadImageUrl(personId);
            String urlPrefix = ResourceUtil.getKmssConfigString("kmss.urlPrefix");
            if (urlPrefix.endsWith("/")) {
                urlPrefix = urlPrefix.substring(0, urlPrefix.lastIndexOf("/"));
            }
            personImageUrl = String.valueOf(urlPrefix) + defaultHeadImageUrl;
        }
        return personImageUrl;
    }
    
    private String handleLongToken(final HttpServletRequest request, String token) {
        final String fdMode = request.getParameter("_w_fdMode");
        if ("write".equals(fdMode)) {
            token = request.getHeader("x-wps-weboffice-token");
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("编辑模式从中台header获取x-wps-weboffice-token, 赋值给w_l_token = {}", token);
            }
        }
        return token;
    }
    
    @GetMapping({ "/v1/3rd/file/info" })
    public Object fileInfo(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("_w_fileId") final String fdId) throws Exception {
        final String fdMode = request.getParameter("_w_fdMode");
        String w_l_token = request.getParameter("_w_l_token");
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取文件信息开始,入参_w_l_token = {},_w_fileId = {}", w_l_token, fdId);
        }
        w_l_token = this.handleLongToken(request, w_l_token);
        if (fdId == null || fdId.isEmpty()) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调获取文件信息失败,_w_fileId为空,入参_w_l_token = {},_w_fileId = {}", w_l_token, fdId);
            }
            response.setStatus(400);
            return null;
        }
        final SysAttMain sysAttMain = (SysAttMain)this.getSysAttMainService().findByPrimaryKey(fdId);
        if (sysAttMain == null) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调获取文件信息失败,无效_w_fileId,入参_w_l_token = {},_w_fileId = {}", w_l_token, fdId);
            }
            response.setStatus(400);
            return null;
        }
        final Boolean ok = this.getSysAttachmentWpsCenterOfficeProvider().validateCallBackToken(w_l_token);
        if (!ok) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调获取文件信息失败,无效token,入参_w_l_token = {},_w_fileId = {}", w_l_token, fdId);
            }
            response.setStatus(401);
            return null;
        }
        final long s = System.currentTimeMillis();
        final String userid = request.getParameter("_w_userid");
        String username = request.getParameter("_w_username");
        String markword = request.getParameter("_w_markWord");
        final String preview_pages = request.getParameter("_w_preview_pages");
        final String rename = request.getParameter("_w_rename");
        final String history = request.getParameter("_w_history");
        final String copy = request.getParameter("_w_copy");
        final String export = request.getParameter("_w_export");
        final String print = request.getParameter("_w_print");
        final String signature = request.getParameter("_w_sign");
        final String value = String.valueOf(copy) + "##" + export + "##" + print;
        final boolean success = WpsUtil.checkSignature(value, userid, signature);
        if (!success) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调获取文件信息失败,签名校验失败,入参_w_l_token = {},_w_fileId = {}, signature = {}, userid = {}, value = {}", w_l_token, fdId, signature, userid, value);
            }
            response.setStatus(401);
            return null;
        }
        final JSONObject jsonObject = new JSONObject();
        try {
            final ISysOrgPersonService sysOrgPersonService = (ISysOrgPersonService)SpringBeanUtil.getBean("sysOrgPersonService");
            final SysOrgPerson sysOrgPerson = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(sysAttMain.getFdCreatorId());
            final String filename = sysAttMain.getFdFileName();
            final JSONObject file = new JSONObject();
            final JSONObject user = new JSONObject();
            final SysOrgPerson person = (SysOrgPerson)sysOrgPersonService.findByPrimaryKey(userid, (Object)SysOrgPerson.class, true);
            if (person != null) {
                username = person.getFdName();
            }
            file.put((Object)"id", (Object)WpsUtil.MD5_32(String.valueOf(fdId) + "@" + sysAttMain.getFdFileId()));
            if (sysAttMain.getFdModelName() != null && sysAttMain.getFdModelName().startsWith("com.landray.kmss.kms.cooperate.model")) {
                file.put((Object)"id", (Object)fdId);
            }
            file.put((Object)"name", (Object)filename);
            file.put((Object)"version", (Object)((sysAttMain.getFdVersion() == null) ? 1 : sysAttMain.getFdVersion()));
            file.put((Object)"size", (Object)new BigDecimal(sysAttMain.getFdSize()));
            file.put((Object)"creator", (Object)sysAttMain.getFdCreatorId());
            file.put((Object)"create_time", (Object)((sysAttMain.getDocCreateTime() != null) ? (sysAttMain.getDocCreateTime().getTime() / 1000L) : (new Date().getTime() / 1000L)));
            file.put((Object)"modifier", (Object)userid);
            file.put((Object)"modify_time", (Object)(new Date().getTime() / 1000L));
            final Map<String, String> additionInfo = new HashMap<String, String>();
            additionInfo.put("token", this.getSysAttachmentWpsCenterOfficeProvider().getOnceCallBackToken(userid, fdId, this.getSysAttachmentWpsCenterOfficeProvider().getWpsToken()));
            file.put((Object)"download_url", (Object)SysAttUtil.generateDownloadUrl(sysAttMain, "wpsCenter", (Map)additionInfo));
            file.put((Object)"preview_pages", (Object)(StringUtils.isEmpty(preview_pages) ? 0 : Integer.valueOf(preview_pages)));
            final JSONObject userAcl = new JSONObject();
            userAcl.put((Object)"rename", (Object)(StringUtils.isEmpty(rename) ? 0 : Integer.valueOf(rename)));
            userAcl.put((Object)"history", (Object)(StringUtils.isEmpty(history) ? 0 : Integer.valueOf(history)));
            userAcl.put((Object)"copy", (Object)(StringUtils.isEmpty(copy) ? 0 : Integer.valueOf(copy)));
            userAcl.put((Object)"export", (Object)(StringUtils.isEmpty(export) ? 0 : Integer.valueOf(export)));
            userAcl.put((Object)"print", (Object)(StringUtils.isEmpty(print) ? 0 : Integer.valueOf(print)));
            file.put((Object)"user_acl", (Object)userAcl);
            final JSONObject watermarkCfg = SysAttViewerUtil.getWaterMarkConfigInDB(Boolean.valueOf(true));
            if ("true".equals(watermarkCfg.get("showWaterMark"))) {
                if (StringUtil.isNull(markword)) {
                    markword = username;
                }
                final JSONObject watermark = new JSONObject();
                watermark.put((Object)"type", (Object)1);
                watermark.put((Object)"value", (Object)markword);
                String markOpacity = "rgba( 192, 192, 192, 0.6 )";
                if (watermarkCfg.get("markOpacity") != null) {
                    markOpacity = "rgba( 192, 192, 192, " + watermarkCfg.get("markOpacity") + ")";
                }
                watermark.put((Object)"fillstyle", (Object)markOpacity);
                String markWordFontFamily = "bold 20px Serif";
                if (watermarkCfg.get("markWordFontFamily") != null) {
                    markWordFontFamily = "bold " + watermarkCfg.get("markWordFontSize") + "px " + watermarkCfg.get("markWordFontFamily");
                }
                watermark.put((Object)"font", (Object)markWordFontFamily);
                watermark.put((Object)"rotate", (Object)(-0.7853982));
                int markRowSpace = 50;
                if (watermarkCfg.get("markRowSpace") != null) {
                    markRowSpace = watermarkCfg.getInt("markRowSpace");
                }
                watermark.put((Object)"horizontal", (Object)markRowSpace);
                int markColSpace = 100;
                if (watermarkCfg.get("markColSpace") != null) {
                    markColSpace = watermarkCfg.getInt("markColSpace");
                }
                watermark.put((Object)"vertical", (Object)markColSpace);
                file.put((Object)"watermark", (Object)watermark);
            }
            else {
                file.put((Object)"watermark", (Object)null);
            }
            jsonObject.put((Object)"file", (Object)file);
            user.put((Object)"id", (Object)userid);
            user.put((Object)"name", (Object)username);
            user.put((Object)"permission", (Object)fdMode);
            user.put((Object)"avatar_url", (Object)this.getPersonImage(userid));
            jsonObject.put((Object)"user", (Object)user);
        }
        catch (final Exception e) {
            SysAttWpsCenterCallbackController.logger.error("WPS回调获取文件信息异常：", e);
        }
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取文件信息完成,入参_w_l_token = {},_w_fileId = {},耗时 = {}, 文件信息 = {}", w_l_token, fdId, System.currentTimeMillis() - s, jsonObject.toString());
        }
        return jsonObject.toString();
    }
    
    @RequestMapping(value = { "/v1/3rd/file/save" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object save(final HttpServletRequest request, final HttpServletResponse response, @RequestParam("_w_userid") final String userId, @RequestParam("file") final MultipartFile file, @RequestParam("_w_fileId") final String fdId) throws Exception {
        String w_l_token = request.getParameter("_w_l_token");
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调保存文件开始,入参_w_l_token = {},_w_fileId = {},_w_userid = {}", w_l_token, fdId, userId);
        }
        w_l_token = this.handleLongToken(request, w_l_token);
        final Boolean ok = this.getSysAttachmentWpsCenterOfficeProvider().validateCallBackToken(w_l_token);
        if (!ok) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调保存文件失败,无效token,入参_w_l_token = {},_w_fileId = {},_w_userid = {}", w_l_token, fdId, userId);
            }
            response.setStatus(401);
            return null;
        }
        final JSONObject jsonObject = new JSONObject();
        final String saveType = request.getHeader("x-weboffice-save-type");
        final String hver = request.getHeader("x-weboffice-save-version");
        int version = 1;
        if (!StringUtil.isNull(hver)) {
            version = Integer.valueOf(hver);
        }
        final JSONObject fileInfo = new JSONObject();
        if (!file.isEmpty() && StringUtil.isNotNull(fdId)) {
            try {
                final SysAttMain sysAttMain = (SysAttMain)this.sysAttMainService.findByPrimaryKey(fdId);
                if (sysAttMain != null) {
                    final InputStream in = file.getInputStream();
                    sysAttMain.setInputStream(in);
                    sysAttMain.setFdSize(new Double(in.available()));
                    this.sysAttMainService.updateByUser((IBaseModel)sysAttMain, userId);
                    fileInfo.put((Object)"id", (Object)WpsUtil.MD5_32(String.valueOf(fdId) + "@" + sysAttMain.getFdFileId()));
                    if (sysAttMain.getFdModelName() != null && sysAttMain.getFdModelName().startsWith("com.landray.kmss.kms.cooperate.model")) {
                        fileInfo.put((Object)"id", (Object)fdId);
                    }
                    fileInfo.put((Object)"name", (Object)sysAttMain.getFdFileName());
                    fileInfo.put((Object)"version", (Object)(version + 1));
                    fileInfo.put((Object)"size", (Object)new BigDecimal(sysAttMain.getFdSize()));
                    fileInfo.put((Object)"download_url", (Object)this.generateDownloadUrl(fdId, this.getSysAttachmentWpsCenterOfficeProvider().getOnceCallBackToken(userId, fdId, this.getSysAttachmentWpsCenterOfficeProvider().getWpsToken())));
                    jsonObject.put((Object)"file", (Object)fileInfo);
                }
            }
            catch (final Exception e) {
                this.log.error("WPS回调保存文件异常", e);
            }
        }
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调保存文件完成,入参_w_l_token = {},_w_fileId = {},_w_userid = {},x-weboffice-save-type = {},新文件 = {}", w_l_token, fdId, userId, saveType, jsonObject.toString());
        }
        return jsonObject.toString();
    }
    
    @PostMapping({ "/expiring" })
    public void expiring(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final StringBuilder jb = new StringBuilder();
        String line = null;
        String sd = null;
        Object deadTime = null;
        try {
            Throwable t = null;
            try {
                final BufferedReader reader = request.getReader();
                try {
                    while ((line = reader.readLine()) != null) {
                        jb.append(line);
                    }
                    final com.alibaba.fastjson.JSONObject jsonObject = com.alibaba.fastjson.JSONObject.parseObject(jb.toString());
                    deadTime = jsonObject.get((Object)"dead_line");
                    final SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                    sd = sdf.format(new Date(Long.parseLong(String.valueOf(deadTime.toString())) * 1000L));
                    final Map<String, String> params = new HashMap<String, String>();
                    params.put("thirdWpsExpiredTime", sd);
                    this.getSysAttachmentWpsCenterOfficeProvider().saveWpsCenterConfig((Map)params);
                    new Thread() {
                        @Override
                        public void run() {
                            SysAttWpsCenterUtil.updateAuthExpiredTodo();
                        }
                    }.start();
                }
                finally {
                    if (reader != null) {
                        reader.close();
                    }
                }
            }
            finally {
                if (t == null) {
                    final Throwable exception;
                    t = exception;
                }
                else {
                    final Throwable exception;
                    if (t != exception) {
                        t.addSuppressed(exception);
                    }
                }
            }
        }
        catch (final Exception e) {
            SysAttWpsCenterCallbackController.logger.error("记录wps中台证书过期时间异常", e);
        }
    }
    
    @PostMapping({ "/v1/3rd/onnotify" })
    public Object onnotify(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(value = "cmd", required = false) final String cmd, @RequestParam(value = "body", required = false) final com.alibaba.fastjson.JSONObject requestBody) {
        final com.alibaba.fastjson.JSONObject result = new com.alibaba.fastjson.JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @PostMapping({ "/v1/3rd/file/view/notify" })
    public Object viewNotify(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(value = "cmd", required = false) final String cmd, @RequestParam(value = "body", required = false) final com.alibaba.fastjson.JSONObject requestBody) {
        final com.alibaba.fastjson.JSONObject result = new com.alibaba.fastjson.JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @PostMapping({ "/v1/3rd/file/online" })
    public Object online(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(value = "ids", required = false) final String[] ids) {
        final com.alibaba.fastjson.JSONObject result = new com.alibaba.fastjson.JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @PostMapping({ "/v1/3rd/file/history" })
    public Object history(final HttpServletRequest request, final HttpServletResponse response, @RequestParam(required = false) final String id, @RequestParam(required = false) final Integer offset, @RequestParam(required = false) final Integer count) {
        final com.alibaba.fastjson.JSONObject result = new com.alibaba.fastjson.JSONObject();
        result.put("result", (Object)0);
        return result;
    }
    
    @RequestMapping(value = { "/integrate/dispatch" }, method = { RequestMethod.POST })
    @ResponseBody
    public Object wpsCenterIntegrateDispatch(final HttpServletRequest request) throws Exception {
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS套红、清稿、转换回调开始,回调接口：/api/sys-attachment/wpsCenterCallback/integrate/dispatch");
        }
        InputStream is = null;
        final StringBuilder callbackInfo = new StringBuilder();
        Label_0183: {
            try {
                is = (InputStream)request.getInputStream();
                final byte[] b = new byte[1024];
                int n;
                while ((n = is.read(b)) != -1) {
                    callbackInfo.append(new String(b, 0, n));
                }
            }
            catch (final IOException e) {
                SysAttWpsCenterCallbackController.logger.error("WPS套红、清稿、转换回调异常", e);
                if (is != null) {
                    try {
                        is.close();
                    }
                    catch (final IOException e2) {
                        SysAttWpsCenterCallbackController.logger.error("WPS套红、清稿、转换回调关闭流出现问题", e2);
                    }
                }
                break Label_0183;
            }
            finally {
                if (is != null) {
                    try {
                        is.close();
                    }
                    catch (final IOException e2) {
                        SysAttWpsCenterCallbackController.logger.error("WPS套红、清稿、转换回调关闭流出现问题", e2);
                    }
                }
            }
            if (is != null) {
                try {
                    is.close();
                }
                catch (final IOException e2) {
                    SysAttWpsCenterCallbackController.logger.error("WPS套红、清稿、转换回调关闭流出现问题", e2);
                }
            }
        }
        if (StringUtil.isNotNull(callbackInfo.toString())) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS中台回调的结果是：" + callbackInfo.toString());
            }
            try {
                final JSONObject jsonObject = JSONObject.fromObject((Object)callbackInfo.toString());
                final String taskId = jsonObject.getString("task_id");
                final Object resultData = jsonObject.get("result");
                final JSONObject resultDataJson = JSONObject.fromObject(resultData);
                final String success = resultDataJson.getString("success");
                final String downloadId = resultDataJson.getString("download_id");
                if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                    SysAttWpsCenterCallbackController.logger.debug("WPS套红、清稿、转换回调信息TaskId：{}, 结果：{}, 下载：{}", taskId, success, downloadId);
                }
                if ("true".equals(success)) {
                    final ISysAttachmentWpsCenterOfficeProvider wpsCenterProvider = (ISysAttachmentWpsCenterOfficeProvider)SpringBeanUtil.getBean("wpsCenterProvider");
                    wpsCenterProvider.dealWpsOperateFile(taskId, downloadId);
                }
                else {
                    SysAttWpsCenterCallbackController.logger.error("WPS中台【转换、清稿、套红】回调的结果是:{}, 因此删除缓存存在任务ID:{}", success, taskId);
                    ConvertRedisCache.getInstance().remove(taskId);
                    ConvertQueueCache.getInstance().remove(taskId);
                    this.getWpsCenterCallbackResult().doCallbackResult(taskId, "failure");
                    WPSCenterCallBusinessUtil.callBack(Boolean.valueOf(false), taskId);
                }
                if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                    SysAttWpsCenterCallbackController.logger.debug("WPS套红、清稿、转换回调完成");
                }
            }
            catch (final Exception e3) {
                SysAttWpsCenterCallbackController.logger.error("WPS套红、清稿、转换回调异常", e3);
            }
        }
        else if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS中台回调时，没有传回任何信息");
        }
        return null;
    }
    
    @GetMapping({ "/audit/show/{controlId}/{fdModelId}" })
    public void auditShowHtml(final HttpServletRequest request, final HttpServletResponse response, @PathVariable("controlId") final String controlId, @PathVariable("fdModelId") final String fdModelId) throws Exception {
        final long s = System.currentTimeMillis();
        final String w_l_token = request.getParameter("_w_l_token");
        final String extendFilePath = request.getParameter("extendFilePath");
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取审批意见控件html开始,入参controlId = {}, fdModelId = {}, extendFilePath = {}, _w_l_token = {}", controlId, fdModelId, extendFilePath, w_l_token);
        }
        final Boolean ok = this.getSysAttachmentWpsCenterOfficeProvider().validateCallBackToken(w_l_token);
        if (!ok) {
            if (SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
                SysAttWpsCenterCallbackController.logger.debug("WPS回调获取审批意见控件html失败,无效token,入参_w_l_token = {}", w_l_token);
            }
            response.setStatus(401);
            return;
        }
        this.downloadAuditShowHtml(request, response, controlId, fdModelId, extendFilePath);
        if (SysAttWpsCenterCallbackController.logger.isDebugEnabled() && SysAttWpsCenterCallbackController.logger.isDebugEnabled()) {
            SysAttWpsCenterCallbackController.logger.debug("WPS回调获取审批意见控件html完成,耗时 = {},入参controlId = {}, fdModelId = {}, extendFilePath = {}, _w_l_token = {}", System.currentTimeMillis() - s, controlId, fdModelId, extendFilePath, w_l_token);
        }
    }
    
    private void downloadAuditShowHtml(final HttpServletRequest request, final HttpServletResponse response, final String controlId, final String fdModelId, final String extendFilePath) {
        PrintWriter printWriter = null;
        String content = "";
        try {
            final ISysFormTemplateService sysFormTemplateService = (ISysFormTemplateService)SpringBeanUtil.getBean("sysFormTemplateService");
            response.setHeader("Content-Disposition", "attachment;filename=\"" + controlId + "_auditShow.html" + "\"");
            response.setContentType("application/octect-stream;charset=UTF-8");
            printWriter = response.getWriter();
            if (StringUtil.isNotNull(controlId) && StringUtil.isNotNull(fdModelId) && StringUtil.isNotNull(extendFilePath)) {
                request.setAttribute("printRequest", (Object)"true");
                content = sysFormTemplateService.getAuditShowContent(fdModelId, controlId, extendFilePath, request);
                if (content != null && content.indexOf("src=") > 0) {
                    content = SysPrintFileUtil.generaPrintData(content);
                }
            }
            printWriter.print(this.genHTMLSource(content));
        }
        catch (final Exception e) {
            e.printStackTrace();
            SysAttWpsCenterCallbackController.logger.error("获取打印页面审批意见失败:" + e.getMessage(), e);
            printWriter.print(this.genHTMLSource(content));
            return;
        }
        finally {
            if (printWriter != null) {
                printWriter.flush();
                printWriter.close();
            }
        }
        if (printWriter != null) {
            printWriter.flush();
            printWriter.close();
        }
    }
    
    private String genHTMLSource(String content) {
        if (StringUtil.isNull(content)) {
            content = "";
        }
        content = content.replace("${picPath}", "");
        final StringBuffer html = new StringBuffer();
        html.append("<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><title>Insert title here</title>");
        html.append("<style type=\"text/css\">");
        html.append("</style></head><body>");
        html.append(content);
        html.append("</body></html>");
        return html.toString();
    }
}
